@@ -317,6 +317,11 @@ The function also requires `ipywidgets`.
                     Auth.validate_token(token)
                     config.set('auth_token', token)
                     _success_callback()
+
+                    post_success = kwargs.get('post_success')
+                    if post_success:
+                        post_success()
+
                     return
                 except AuthenticationFailedError:
                     pass
@@ -338,6 +343,11 @@ The function also requires `ipywidgets`.
             try:
                 Auth.validate_token(token)
                 display(success_widget)
+
+                post_success = kwargs.get('post_success')
+                if post_success:
+                    post_success()
+
                 return
             except AuthenticationFailedError:
                 pass
